@@ -30,4 +30,4 @@ def main(args):
         raise
 
 if __name__ == '__main__':
-    common.main(__file__)
+    common.main(__file__, main)
